
# Type: sequence variant modulates treatment association_object




URI: [biolink:sequence_variant_modulates_treatment_association_object](https://w3id.org/biolink/vocab/sequence_variant_modulates_treatment_association_object)


## Domain and Range

[SequenceVariantModulatesTreatmentAssociation](SequenceVariantModulatesTreatmentAssociation.md) ->  <sub>REQ</sub> [Treatment](Treatment.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [SequenceVariantModulatesTreatmentAssociation](SequenceVariantModulatesTreatmentAssociation.md)
